@@ -1,7 +1,9 @@
+mod call;
 mod from_closure;
 mod from_function;
 mod to_closure;
 
+pub use call::*;
 pub use from_closure::*;
 pub use from_function::*;
 pub use to_closure::*;
